You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by jp...@apache.org on 2023/06/26 12:05:18 UTC

[lucene] branch branch_9_7 updated: Add next bugfix version 9.7.1

This is an automated email from the ASF dual-hosted git repository.

jpountz pushed a commit to branch branch_9_7
in repository https://gitbox.apache.org/repos/asf/lucene.git


The following commit(s) were added to refs/heads/branch_9_7 by this push:
     new 590b9bc3717 Add next bugfix version 9.7.1
590b9bc3717 is described below

commit 590b9bc37178c98de0a8eded488fea8b5abf5ca5
Author: Adrien Grand <jp...@gmail.com>
AuthorDate: Mon Jun 26 14:05:06 2023 +0200

    Add next bugfix version 9.7.1
---
 build.gradle                                             |  2 +-
 lucene/CHANGES.txt                                       |  6 ++++++
 lucene/core/src/java/org/apache/lucene/util/Version.java | 11 ++++++++---
 3 files changed, 15 insertions(+), 4 deletions(-)

diff --git a/build.gradle b/build.gradle
index 0eae57bd10f..4f5fcfdab27 100644
--- a/build.gradle
+++ b/build.gradle
@@ -36,7 +36,7 @@ apply from: file('gradle/globals.gradle')
 // Calculate project version:
 version = {
   // Release manager: update base version here after release:
-  String baseVersion = '9.7.0'
+  String baseVersion = '9.7.1'
 
   // On a release explicitly set release version in one go:
   //  -Dversion.release=x.y.z
diff --git a/lucene/CHANGES.txt b/lucene/CHANGES.txt
index c67d1f295d0..a9dd4da35e6 100644
--- a/lucene/CHANGES.txt
+++ b/lucene/CHANGES.txt
@@ -3,6 +3,12 @@ Lucene Change Log
 For more information on past and future Lucene versions, please see:
 http://s.apache.org/luceneversions
 
+======================== Lucene 9.7.1 =======================
+
+Bug Fixes
+---------------------
+(No changes)
+
 ======================== Lucene 9.7.0 =======================
 
 API Changes
diff --git a/lucene/core/src/java/org/apache/lucene/util/Version.java b/lucene/core/src/java/org/apache/lucene/util/Version.java
index bd37efbd818..e7c86cdb0ab 100644
--- a/lucene/core/src/java/org/apache/lucene/util/Version.java
+++ b/lucene/core/src/java/org/apache/lucene/util/Version.java
@@ -264,11 +264,16 @@ public final class Version {
   @Deprecated public static final Version LUCENE_9_6_0 = new Version(9, 6, 0);
 
   /**
-   * Match settings and bugs in Lucene's 9.7.0 release.
+   * @deprecated (9.7.1) Use latest
+   */
+  @Deprecated public static final Version LUCENE_9_7_0 = new Version(9, 7, 0);
+
+  /**
+   * Match settings and bugs in Lucene's 9.7.1 release.
    *
    * <p>Use this to get the latest &amp; greatest settings, bug fixes, etc, for Lucene.
    */
-  public static final Version LUCENE_9_7_0 = new Version(9, 7, 0);
+  public static final Version LUCENE_9_7_1 = new Version(9, 7, 1);
 
   // To add a new version:
   //  * Only add above this comment
@@ -284,7 +289,7 @@ public final class Version {
    * <b>re-test your entire application</b> to ensure it behaves as expected, as some defaults may
    * have changed and may break functionality in your application.
    */
-  public static final Version LATEST = LUCENE_9_7_0;
+  public static final Version LATEST = LUCENE_9_7_1;
 
   /**
    * Constant for backwards compatibility.